﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using Privileges.Model;

namespace Privileges
{
    [TestClass]
    public class AuthorsShould
    {
        private User _author;

        [TestInitialize]
        public void Setup()
        {
            _author = new User();
            _author.AddToRole(Roles.Authors);
        }

        [TestMethod]
        public void BeAbleToCreateArticles()
        {
            var priv = new ArticlePrivilege();
            bool result = priv.CanCreate(new Article(), _author);

            Assert.IsTrue(result, "Should be able to create a new article.");
        }

        [TestMethod]
        public void BeAbleToEditTheirOwnArticles()
        {
            var priv = new ArticlePrivilege();
            var myArticle = new Article();
            myArticle.Author = _author;
            bool result = priv.CanEdit(myArticle, _author);

            Assert.IsTrue(result, "Should have access to own article.");
        }

        [TestMethod]
        public void NotBeAbleToEditOtherAuthorsArticles()
        {
            var priv = new ArticlePrivilege();
            var anotherArticle = new Article();
            anotherArticle.Author = new User();
            bool result = priv.CanEdit(anotherArticle, _author);

            Assert.IsFalse(result, "Should not have access to others' articles.");
        }
    }
}