﻿using Microsoft.VisualStudio.TestTools.UnitTesting;
using Privileges.Model;

namespace Privileges
{
    [TestClass]
    public class EditorsShould
    {
        private User _editor;

        [TestInitialize]
        public void Setup()
        {
            _editor = new User();
            _editor.AddToRole(Roles.Editors);
        }

        [TestMethod]
        public void NotBeAbleToCreateArticles()
        {
            var priv = new ArticlePrivilege();
            bool result = priv.CanCreate(new Article(), _editor);

            Assert.IsFalse(result, "Should not be able to create a new article - only authors do this.");
        }

        [TestMethod]
        public void BeAbleToEditTheirOwnArticles()
        {
            var priv = new ArticlePrivilege();
            var myArticle = new Article();
            myArticle.Author = _editor;
            bool result = priv.CanEdit(myArticle, _editor);

            Assert.IsTrue(result, "Should have access to own article.");
        }

        [TestMethod]
        public void BeAbleToEditOtherAuthorsArticles()
        {
            var priv = new ArticlePrivilege();
            var anotherArticle = new Article();
            anotherArticle.Author = new User();
            bool result = priv.CanEdit(anotherArticle, _editor);

            Assert.IsTrue(result, "Should have access to others' articles, too, as an editor.");
        }
    }
}